@@ -63,6 +63,7 @@ def query(
                 not in ['QUEUED', 'RUNNING']:
             next_token = None
             data = []
+            columns = []
 
             while True:
                 if next_token is not None:
@@ -77,7 +78,9 @@ def query(
 
                 rows = utils.dict_query(dictionary=response, path='ResultSet.Rows')
 
-                columns = [column.get('VarCharValue') for column in rows[0].get('Data')]
+                # Columns are only supplied on the first page
+                if next_token is None:
+                    columns = [column.get('VarCharValue') for column in rows[0].get('Data')]
 
                 count = 0
                 for row in rows:
