@@ -112,13 +112,9 @@ class RedisHelper:
                 "No pattern given. To delete all keys, "
                 "pattern = '*' or use a more specific pattern to match keys with "
             ))
-        key = self.redis_conn.scan_iter(pattern)
 
-        if key is not None:
-            if isinstance(key, str):
-                key = [key]
-            # run mass delete
-            self.redis_delete(keys=key)
+        keys = list(self.redis_conn.scan_iter(pattern))
+        self.redis_conn.delete(*keys)
 
     def redis_hexists(self, *, hashkey: str):
         """Check hashkey exists in store"""
