@@ -20,18 +20,27 @@ class ExtendedSafeLoader(yaml.SafeLoader):
         super().__init__(stream)
 
     def include(self, node):
-        """macro to include !include function to yaml.load"""
+        """yaml.load macro to add !include function to import other yamls into current"""
         filename = os.path.join(self._root, self.construct_scalar(node))
         with open(filename, 'r') as file_:
             return yaml.load(file_, Loader=ExtendedSafeLoader)
 
     def join(self, node):
-        """macro to include !join function to yaml.load"""
+        """yaml.load macro to include string !join function"""
         seq = self.construct_sequence(node)
         return ''.join([str(i) for i in seq])
 
     def load_sql(self, node):
-        """macro to include !load_sql function to yaml.load"""
+        """yaml.load macro to include !load_sql function"""
         filename = os.path.join(self._root, self.construct_scalar(node))
         with open(filename, 'r') as file_:
             return file_.read()
+
+    def load_env(self, node):
+        """yaml.load macro to include !env function"""
+        env_var_name = self.construct_scalar(node)
+        return os.environ[env_var_name]
+
+    def fullpath(self, node):
+        """yaml.load macro to get fullpath of python __main__ file"""
+        return os.path.join(self._root, self.construct_scalar(node))
